setwd("C:/Users/Faith/Desktop/2019 Pecker Points/2019 Data/USE/All Final Results/Nest Success Data")


nests <- read.csv("species.nest.csv", header=TRUE, sep=",")

BEWR <- nests[nests$species == "BEWR", ]
ATBC <- nests[nests$species == "ATBC", ]
ATBC <- nests[nests$species == "ATBC", ]
BCTI <- nests[nests$species == "BCTI", ]

library(lme4)
library(car)
library(MASS)
library(AICcmodavg)
library(MuMIn)
library(tidyverse)
library(GGally)
require(arm)





# setting baseline for predicted variable

BEWR$nest.fate <- relevel(BEWR$nest.fate, "failed")
BEWR$origin <- relevel(BEWR$origin, "natural")

ATBC$nest.fate <- relevel(ATBC$nest.fate, "failed")
ATBC$origin <- relevel(ATBC$origin, "natural")

ATBC$nest.fate <- relevel(ATBC$nest.fate, "failed")
ATBC$origin <- relevel(ATBC$origin, "natural")

BCTI$nest.fate <- relevel(BCTI$nest.fate, "failed")
BCTI$origin <- relevel(BCTI$origin, "natural")



# scaling continuous values for nest success

BEWR$scaledDBH <- scale(BEWR$DBH)
BEWR$scaledheight <- scale(BEWR$height)
BEWR$scaledhole <- scale(BEWR$hole)
BEWR$scaleddepth <- scale(BEWR$depth)

ATBC$scaledDBH <- scale(ATBC$DBH)
ATBC$scaledheight <- scale(ATBC$height)
ATBC$scaledhole <- scale(ATBC$hole)
ATBC$scaleddepth <- scale(ATBC$depth)

ATBC$scaledDBH <- scale(ATBC$DBH)
ATBC$scaledheight <- scale(ATBC$height)
ATBC$scaledhole <- scale(ATBC$hole)
ATBC$scaleddepth <- scale(ATBC$depth)

BCTI$scaledDBH <- scale(BCTI$DBH)
BCTI$scaledheight <- scale(BCTI$height)
BCTI$scaledhole <- scale(BCTI$hole)
BCTI$scaleddepth <- scale(BCTI$depth)


# vif's for the independent variables already shown to be under 1.5. 

#pseudo R2 needs package DescTools
library(DescTools)

### BEWR

# null model 

NullBEWR <- glm(nest.fate ~ 1, family="binomial", data=BEWR, na.action = na.fail)
summary(NullBEWR)

# building the logistic regression model selector 
BEWR.glm <- glm(nest.fate ~ nest.cover + origin + scaledheight + decay + scaledDBH + scaledhole + scaleddepth, family="binomial", data=BEWR, na.action = na.fail)

BEWR_fits <- dredge(BEWR.glm)
options(digits = 2)
model.sel(BEWR_fits)

# best models, only two within 2 delta AIC: 
# model 1: nest.cover, origin, scaledDBH
# model 2: nest.cover, origin, scaledDBH, scaledhole

BEWR.1 <- glm(nest.fate ~ nest.cover + origin + scaledDBH, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.2 <- glm(nest.fate ~ nest.cover + origin + scaledDBH + scaledhole, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.3 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.4 <- glm(nest.fate ~ nest.cover + origin + scaledDBH + scaledheight, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.5 <- glm(nest.fate ~ nest.cover + origin + scaledDBH + scaleddepth, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.6 <- glm(nest.fate ~ nest.cover + origin, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.7 <- glm(nest.fate ~ decay + nest.cover + origin, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.8 <- glm(nest.fate ~ nest.cover + origin + scaledhole, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.9 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH + scaledhole, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.10 <- glm(nest.fate ~ nest.cover + origin + scaledDBH + scaleddepth + scaledhole, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.11 <- glm(nest.fate ~ nest.cover + origin + scaledDBH + scaledheight + scaledhole, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.12 <- glm(nest.fate ~ nest.cover + scaledDBH, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.13 <- glm(nest.fate ~ nest.cover + origin + scaleddepth, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.14 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH + scaledheight, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.15 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH + scaleddepth, family = "binomial", data = BEWR, na.action = na.fail)

BEWR.16 <- glm(nest.fate ~ nest.cover + origin + scaledDBH + scaleddepth + scaledheight, family = "binomial", data = BEWR, na.action = na.fail)




#pseudo R2
PseudoR2(ma_df, c("CoxSnell"))

#Set up candidate model list for model averaging
BEWRcand.set <- list(BEWR.1, BEWR.2, BEWR.3, BEWR.4, BEWR.5, BEWR.6, BEWR.7, BEWR.8, BEWR.9, BEWR.10, BEWR.11, BEWR.12, BEWR.13, BEWR.14, BEWR.15, BEWR.16)

ma_df <- model.avg(BEWRcand.set)
ma_coefs <- coefTable(ma_df, full=TRUE, adjust.se = TRUE)
coefnames <- row.names(ma_coefs)
ma_coefs <- as.data.frame(ma_coefs)
ma_coefs <- mutate(ma_coefs,
                   coefficient = coefnames,
                   t = Estimate / `Std. Error`,
                   p = pt(abs(t), df = 100, lower.tail = FALSE),
                   lower95 = Estimate - 1.96 * `Std. Error`,
                   upper95 = Estimate + 1.96 * `Std. Error`) %>% select(coefficient, Estimate, `Std. Error`, t, p, lower95, upper95)
knitr::kable(ma_coefs, digits = 4)

# only nest.cover and origin are significant 



### ATFL

ATBC.glm <- glm(nest.fate ~ nest.cover + origin + scaledheight + decay + scaledDBH + scaledhole + scaleddepth, family="binomial", data=ATBC, na.action = na.pass)

ATBC.model.comparison <- dredge(ATBC.glm)
head(ATBC.model.comparison)

# best models within >.9 weight of top 

ATBC.1 <- glm(nest.fate ~ decay + origin + scaledDBH + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.2 <- glm(nest.fate ~ decay + origin + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.3 <- glm(nest.fate ~ decay + nest.cover + origin + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.4 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.5 <- glm(nest.fate ~ decay + origin + scaleddepth + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.6 <- glm(nest.fate ~ decay + origin + scaledDBH + scaledheight + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.7 <- glm(nest.fate ~ decay + origin + scaledDBH + scaleddepth + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.8 <- glm(nest.fate ~ decay + origin + scaledDBH, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.9 <- glm(nest.fate ~ decay + origin + scaledheight + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.10 <- glm(nest.fate ~ decay + origin, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.11 <- glm(nest.fate ~ decay + nest.cover + origin + scaleddepth + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.12 <- glm(nest.fate ~ decay + nest.cover + origin + scaledheight + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.13 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH + scaledheight + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.14 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH + scaleddepth + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.15 <- glm(nest.fate ~ decay + origin + scaledDBH + scaledheight, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.16 <- glm(nest.fate ~ decay + origin + scaleddepth + scaledheight + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.17 <- glm(nest.fate ~ decay + origin + scaledDBH + scaleddepth + scaledheight + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.18 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.19 <- glm(nest.fate ~ decay + nest.cover + origin, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.20 <- glm(nest.fate ~ decay + origin + scaledheight, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.21 <- glm(nest.fate ~ origin + scaledhole, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.22 <- glm(nest.fate ~ decay + origin + scaledDBH + scaleddepth, family = "binomial", data = ATBC, na.action = na.fail)

ATBC.23 <- glm(nest.fate ~ decay + origin + scaleddepth, family = "binomial", data = ATBC, na.action = na.fail)



#Set up candidate model list for model averaging
ATBCcand.set <- list(ATBC.1, ATBC.2, ATBC.3, ATBC.4, ATBC.5, ATBC.6, ATBC.7, ATBC.8, ATBC.9, ATBC.10, ATBC.11, ATBC.12, ATBC.13, ATBC.14, ATBC.15, ATBC.16, ATBC.17, ATBC.18, ATBC.19, ATBC.20, ATBC.21, ATBC.22, ATBC.23)

ma_df <- model.avg(ATBCcand.set)
ma_coefs <- coefTable(ma_df, full=TRUE, adjust.se = TRUE)
coefnames <- row.names(ma_coefs)
ma_coefs <- as.data.frame(ma_coefs)
ma_coefs <- mutate(ma_coefs,
                   coefficient = coefnames,
                   t = Estimate / `Std. Error`,
                   p = pt(abs(t), df = 100, lower.tail = FALSE),
                   lower95 = Estimate - 1.96 * `Std. Error`,
                   upper95 = Estimate + 1.96 * `Std. Error`) %>% select(coefficient, Estimate, `Std. Error`, t, p, lower95, upper95)
knitr::kable(ma_coefs, digits = 4)







### GFWO

GFWO.1 <- glm(nest.fate ~ decay + nest.cover, family = "binomial", data = GFWO, na.action = na.fail)

GFWO.2 <- glm(nest.fate ~ decay + nest.cover + scaledDBH, family = "binomial", data = GFWO, na.action = na.fail)

GFWO.3 <- glm(nest.fate ~ decay + nest.cover + scaledhole, family = "binomial", data = GFWO, na.action = na.fail)

GFWO.4 <- glm(nest.fate ~ decay + nest.cover + scaledheight, family = "binomial", data = GFWO, na.action = na.fail)

GFWO.5 <- glm(nest.fate ~ decay + nest.cover + scaleddepth, family = "binomial", data = GFWO, na.action = na.fail)

GFWO.6 <- glm(nest.fate ~ decay + nest.cover + scaledDBH + scaleddepth, family = "binomial", data = GFWO, na.action = na.fail)

GFWO.7 <- glm(nest.fate ~ decay + nest.cover + scaledDBH+ scaledhole, family = "binomial", data = GFWO, na.action = na.fail)

GFWO.8 <- glm(nest.fate ~ decay + nest.cover + scaledDBH + scaledheight, family = "binomial", data = GFWO, na.action = na.fail)

GFWO.9 <- glm(nest.fate ~ decay + nest.cover + scaledheight + scaledhole, family = "binomial", data = GFWO, na.action = na.fail)

#Set up candidate model list for model averaging
GFWOcand.set <- list(GFWO.1, GFWO.2, GFWO.3, GFWO.4, GFWO.5, GFWO.6, GFWO.7, GFWO.8, GFWO.9)

ma_df <- model.avg(GFWOcand.set)
ma_coefs <- coefTable(ma_df, full=TRUE, adjust.se = TRUE)
coefnames <- row.names(ma_coefs)
ma_coefs <- as.data.frame(ma_coefs)
ma_coefs <- mutate(ma_coefs,
                   coefficient = coefnames,
                   t = Estimate / `Std. Error`,
                   p = pt(abs(t), df = 100, lower.tail = FALSE),
                   lower95 = Estimate - 1.96 * `Std. Error`,
                   upper95 = Estimate + 1.96 * `Std. Error`) %>% select(coefficient, Estimate, `Std. Error`, t, p, lower95, upper95)
knitr::kable(ma_coefs, digits = 4)





## BCTI

BCTI.1 <- glm(nest.fate ~ decay + nest.cover + origin, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.2 <- glm(nest.fate ~ decay + origin, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.3 <- glm(nest.fate ~ decay + nest.cover + origin + scaledheight, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.4 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.5 <- glm(nest.fate ~ decay + nest.cover + origin + scaledhole, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.6 <- glm(nest.fate ~ decay + nest.cover + origin + scaleddepth, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.7 <- glm(nest.fate ~ decay + origin + scaledDBH, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.8 <- glm(nest.fate ~ decay + origin + scaleddepth, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.9 <- glm(nest.fate ~ decay + origin + scaledheight, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.10 <- glm(nest.fate ~ decay + origin + scaledhole, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.11 <- glm(nest.fate ~ decay + nest.cover, family = "binomial", data = BCTI, na.action = na.fail)

BCTI.12 <- glm(nest.fate ~ decay + nest.cover + origin + scaledDBH + scaledheight, family = "binomial", data = BCTI, na.action = na.fail)

# list models

BCTIcand.set <- list(BCTI.1, BCTI.2, BCTI.3, BCTI.4, BCTI.5, BCTI.6, BCTI.7, BCTI.8, BCTI.9, BCTI.10, BCTI.11, BCTI.12)

ma_df <- model.avg(BCTIcand.set)
ma_coefs <- coefTable(ma_df, full=TRUE, adjust.se = TRUE)
coefnames <- row.names(ma_coefs)
ma_coefs <- as.data.frame(ma_coefs)
ma_coefs <- mutate(ma_coefs,
                   coefficient = coefnames,
                   t = Estimate / `Std. Error`,
                   p = pt(abs(t), df = 100, lower.tail = FALSE),
                   lower95 = Estimate - 1.96 * `Std. Error`,
                   upper95 = Estimate + 1.96 * `Std. Error`) %>% select(coefficient, Estimate, `Std. Error`, t, p, lower95, upper95)
knitr::kable(ma_coefs, digits = 4)

mb.gof.test(ma_df, nsim = 5, plot.hist = TRUE)







##Conduct model averaging using candidate list and all predictors in said candidate list

nest_cover <- modavg(BCTIcand.set, "nest.cover", modnames = NULL, 
       second.ord = TRUE, nobs = NULL, uncond.se = "revised")
head(nest_cover)

BCTInvAVG <- function(nest_cover, print.table = TRUE){
  UseMethod("mb.chisq", mod)
}

BCTInvAVG


decay <- modavg(ATBCcand2.set, "decay", modnames = NULL, 
       second.ord = TRUE, nobs = NULL, uncond.se = "revised")
head(decay)

modavg(cand.set, "scaledTotal.length", modnames = NULL, 
       second.ord = TRUE, nobs = NULL, uncond.se = "revised")

modavg(cand.set, "scaledHEIGHTFOCBAT", modnames = NULL, 
       second.ord = TRUE, nobs = NULL, uncond.se = "revised")

modavg(cand.set, "scaledPropFromPortal", modnames = NULL, 
       second.ord = TRUE, nobs = NULL, uncond.se = "revised")

































# Blog way 
ma_df <- model.avg(fits)
ma_coefs <- coefTable(ma_df, full=TRUE, adjust.se = TRUE)
coefnames <- row.names(ma_coefs)
ma_coefs <- as.data.frame(ma_coefs)
ma_coefs <- mutate(ma_coefs,
                   coefficient = coefnames,
                   t = Estimate / `Std. Error`,
                   p = pt(abs(t), df = 195, lower.tail = FALSE),
                   lower95 = Estimate - 1.96 * `Std. Error`,
                   upper95 = Estimate + 1.96 * `Std. Error`) %>% select(coefficient, Estimate, `Std. Error`, t, p, lower95, upper95)
knitr::kable(ma_coefs, digits = 2)

